@@ -27,15 +27,19 @@ class FarOpt(object):
                     
                     if output['OutputKey']=='s3asyncoutput':
                         self.asyncbucket = output['OutputValue']
+                        logging.info('Async Bucket: ' + self.asyncbucket)
                     
                     if output['OutputKey']=='s3output':
                         self.bucket = output['OutputValue']
+                        logging.info('Bucket: ' + self.bucket)
                     
                     if output['OutputKey']=='recipetable':
                         self.recipetable = output['OutputValue']
+                        logging.info('Recipe Table: ' + self.recipetable)
                     
                     if output['OutputKey']=='jobtable':
                         self.jobtable = output['OutputValue']
+                        logging.info('Job table: ' + self.jobtable)
                 
                 self.configured = False
                 self.submitted = False
